@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.06_03'; # TRIAL VERSION
+our $VERSION = '0.08_01'; # TRIAL VERSION
 
 use Exporter;
 use parent 'Exporter';
@@ -384,7 +384,7 @@ Date::Easy::Datetime - easy datetime class
 
 =head1 VERSION
 
-This document describes version 0.06_03 of Date::Easy::Datetime.
+This document describes version 0.08_01 of Date::Easy::Datetime.
 
 =head1 SYNOPSIS
 
@@ -457,8 +457,8 @@ with epoch seconds.
 =head3 UTC
 
 'UTC' means to use the UTC timzeone, which essentialy means to ignore timezone altogether.  That is,
-under 'UTC' Date::Easy::Datetime will use C<gmtime> and C<timegm> (technically, C<timegm_local>,
-from L<Time::Local>) to deal with epcoh seconds.
+under 'UTC' Date::Easy::Datetime will use C<gmtime> and C<timegm> (technically, C<timegm_modern>,
+from L<Time::Local>) to deal with epoch seconds.
 
 =head3 GMT
 
